@@ -1,70 +1,72 @@
-( cd opt/kde/share/doc/HTML/en/krdc ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/krdc ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/krfb ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/krfb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kppp ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kppp ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libkgetcore.so.4 )
+( cd opt/kde/lib ; ln -sf libkgetcore.so.4.4.0 libkgetcore.so.4 )
+( cd opt/kde/lib ; rm -rf libkgetcore.so )
+( cd opt/kde/lib ; ln -sf libkgetcore.so.4 libkgetcore.so )
+( cd opt/kde/lib ; rm -rf libkopete.so.4 )
+( cd opt/kde/lib ; ln -sf libkopete.so.4.4.0 libkopete.so.4 )
+( cd opt/kde/lib ; rm -rf libkopete.so )
+( cd opt/kde/lib ; ln -sf libkopete.so.4 libkopete.so )
+( cd opt/kde/lib ; rm -rf libkopete_videodevice.so.4 )
+( cd opt/kde/lib ; ln -sf libkopete_videodevice.so.4.4.0 libkopete_videodevice.so.4 )
+( cd opt/kde/lib ; rm -rf libkopete_videodevice.so )
+( cd opt/kde/lib ; ln -sf libkopete_videodevice.so.4 libkopete_videodevice.so )
+( cd opt/kde/lib ; rm -rf libkopeteaddaccountwizard.so.1 )
+( cd opt/kde/lib ; ln -sf libkopeteaddaccountwizard.so.1.0.0 libkopeteaddaccountwizard.so.1 )
+( cd opt/kde/lib ; rm -rf libkopeteaddaccountwizard.so )
+( cd opt/kde/lib ; ln -sf libkopeteaddaccountwizard.so.1 libkopeteaddaccountwizard.so )
+( cd opt/kde/lib ; rm -rf libkopetestatusmenu.so.1 )
+( cd opt/kde/lib ; ln -sf libkopetestatusmenu.so.1.0.0 libkopetestatusmenu.so.1 )
+( cd opt/kde/lib ; rm -rf libkopetestatusmenu.so )
+( cd opt/kde/lib ; ln -sf libkopetestatusmenu.so.1 libkopetestatusmenu.so )
+( cd opt/kde/lib ; rm -rf libkopeteidentity.so.1 )
+( cd opt/kde/lib ; ln -sf libkopeteidentity.so.1.0.0 libkopeteidentity.so.1 )
+( cd opt/kde/lib ; rm -rf libkopeteidentity.so )
+( cd opt/kde/lib ; ln -sf libkopeteidentity.so.1 libkopeteidentity.so )
+( cd opt/kde/lib ; rm -rf libkopetecontactlist.so.1 )
+( cd opt/kde/lib ; ln -sf libkopetecontactlist.so.1.0.0 libkopetecontactlist.so.1 )
+( cd opt/kde/lib ; rm -rf libkopetecontactlist.so )
+( cd opt/kde/lib ; ln -sf libkopetecontactlist.so.1 libkopetecontactlist.so )
+( cd opt/kde/lib ; rm -rf libkopetechatwindow_shared.so.1 )
+( cd opt/kde/lib ; ln -sf libkopetechatwindow_shared.so.1.0.0 libkopetechatwindow_shared.so.1 )
+( cd opt/kde/lib ; rm -rf libkopetechatwindow_shared.so )
+( cd opt/kde/lib ; ln -sf libkopetechatwindow_shared.so.1 libkopetechatwindow_shared.so )
+( cd opt/kde/lib ; rm -rf libkopete_oscar.so.4 )
+( cd opt/kde/lib ; ln -sf libkopete_oscar.so.4.4.0 libkopete_oscar.so.4 )
+( cd opt/kde/lib ; rm -rf libkopete_oscar.so )
+( cd opt/kde/lib ; ln -sf libkopete_oscar.so.4 libkopete_oscar.so )
+( cd opt/kde/lib ; rm -rf liboscar.so.1 )
+( cd opt/kde/lib ; ln -sf liboscar.so.1.0.0 liboscar.so.1 )
+( cd opt/kde/lib ; rm -rf liboscar.so )
+( cd opt/kde/lib ; ln -sf liboscar.so.1 liboscar.so )
+( cd opt/kde/lib ; rm -rf libkyahoo.so.1 )
+( cd opt/kde/lib ; ln -sf libkyahoo.so.1.0.0 libkyahoo.so.1 )
+( cd opt/kde/lib ; rm -rf libkyahoo.so )
+( cd opt/kde/lib ; ln -sf libkyahoo.so.1 libkyahoo.so )
+( cd opt/kde/lib ; rm -rf libkopeteprivacy.so.1 )
+( cd opt/kde/lib ; ln -sf libkopeteprivacy.so.1.0.0 libkopeteprivacy.so.1 )
+( cd opt/kde/lib ; rm -rf libkopeteprivacy.so )
+( cd opt/kde/lib ; ln -sf libkopeteprivacy.so.1 libkopeteprivacy.so )
+( cd opt/kde/lib ; rm -rf libkopete_otr_shared.so.1 )
+( cd opt/kde/lib ; ln -sf libkopete_otr_shared.so.1.0.0 libkopete_otr_shared.so.1 )
+( cd opt/kde/lib ; rm -rf libkopete_otr_shared.so )
+( cd opt/kde/lib ; ln -sf libkopete_otr_shared.so.1 libkopete_otr_shared.so )
+( cd opt/kde/lib ; rm -rf libkrdccore.so.4 )
+( cd opt/kde/lib ; ln -sf libkrdccore.so.4.4.0 libkrdccore.so.4 )
+( cd opt/kde/lib ; rm -rf libkrdccore.so )
+( cd opt/kde/lib ; ln -sf libkrdccore.so.4 libkrdccore.so )
+( cd opt/kde/lib ; rm -rf libkrfbprivate.so )
+( cd opt/kde/lib ; ln -sf libkrfbprivate.so.4.4.0 libkrfbprivate.so )
 ( cd opt/kde/share/doc/HTML/en/kget ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kget ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kopete ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kopete ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/lib ; rm -rf libkopete.so.4 )
-( cd opt/kde/lib ; ln -sf libkopete.so.4.3.0 libkopete.so.4 )
-( cd opt/kde/lib ; rm -rf libkopeteprivacy.so.1 )
-( cd opt/kde/lib ; ln -sf libkopeteprivacy.so.1.0.0 libkopeteprivacy.so.1 )
-( cd opt/kde/lib ; rm -rf libkopete_oscar.so )
-( cd opt/kde/lib ; ln -sf libkopete_oscar.so.4 libkopete_oscar.so )
-( cd opt/kde/lib ; rm -rf libkopetestatusmenu.so.1 )
-( cd opt/kde/lib ; ln -sf libkopetestatusmenu.so.1.0.0 libkopetestatusmenu.so.1 )
-( cd opt/kde/lib ; rm -rf libkgetcore.so )
-( cd opt/kde/lib ; ln -sf libkgetcore.so.4 libkgetcore.so )
-( cd opt/kde/lib ; rm -rf libkopeteaddaccountwizard.so.1 )
-( cd opt/kde/lib ; ln -sf libkopeteaddaccountwizard.so.1.0.0 libkopeteaddaccountwizard.so.1 )
-( cd opt/kde/lib ; rm -rf libkopetestatusmenu.so )
-( cd opt/kde/lib ; ln -sf libkopetestatusmenu.so.1 libkopetestatusmenu.so )
-( cd opt/kde/lib ; rm -rf libkopetechatwindow_shared.so )
-( cd opt/kde/lib ; ln -sf libkopetechatwindow_shared.so.1 libkopetechatwindow_shared.so )
-( cd opt/kde/lib ; rm -rf liboscar.so )
-( cd opt/kde/lib ; ln -sf liboscar.so.1 liboscar.so )
-( cd opt/kde/lib ; rm -rf libkopete_videodevice.so )
-( cd opt/kde/lib ; ln -sf libkopete_videodevice.so.4 libkopete_videodevice.so )
-( cd opt/kde/lib ; rm -rf libkyahoo.so )
-( cd opt/kde/lib ; ln -sf libkyahoo.so.1 libkyahoo.so )
-( cd opt/kde/lib ; rm -rf libkopete_videodevice.so.4 )
-( cd opt/kde/lib ; ln -sf libkopete_videodevice.so.4.3.0 libkopete_videodevice.so.4 )
-( cd opt/kde/lib ; rm -rf libkrdccore.so )
-( cd opt/kde/lib ; ln -sf libkrdccore.so.4 libkrdccore.so )
-( cd opt/kde/lib ; rm -rf libkyahoo.so.1 )
-( cd opt/kde/lib ; ln -sf libkyahoo.so.1.0.0 libkyahoo.so.1 )
-( cd opt/kde/lib ; rm -rf libkopetecontactlist.so.1 )
-( cd opt/kde/lib ; ln -sf libkopetecontactlist.so.1.0.0 libkopetecontactlist.so.1 )
-( cd opt/kde/lib ; rm -rf libkopeteaddaccountwizard.so )
-( cd opt/kde/lib ; ln -sf libkopeteaddaccountwizard.so.1 libkopeteaddaccountwizard.so )
-( cd opt/kde/lib ; rm -rf libkopeteidentity.so.1 )
-( cd opt/kde/lib ; ln -sf libkopeteidentity.so.1.0.0 libkopeteidentity.so.1 )
-( cd opt/kde/lib ; rm -rf libkgetcore.so.4 )
-( cd opt/kde/lib ; ln -sf libkgetcore.so.4.3.0 libkgetcore.so.4 )
-( cd opt/kde/lib ; rm -rf libkopetechatwindow_shared.so.1 )
-( cd opt/kde/lib ; ln -sf libkopetechatwindow_shared.so.1.0.0 libkopetechatwindow_shared.so.1 )
-( cd opt/kde/lib ; rm -rf libkopete_otr_shared.so )
-( cd opt/kde/lib ; ln -sf libkopete_otr_shared.so.1 libkopete_otr_shared.so )
-( cd opt/kde/lib ; rm -rf libkopete_otr_shared.so.1 )
-( cd opt/kde/lib ; ln -sf libkopete_otr_shared.so.1.0.0 libkopete_otr_shared.so.1 )
-( cd opt/kde/lib ; rm -rf libkopetecontactlist.so )
-( cd opt/kde/lib ; ln -sf libkopetecontactlist.so.1 libkopetecontactlist.so )
-( cd opt/kde/lib ; rm -rf libkopeteprivacy.so )
-( cd opt/kde/lib ; ln -sf libkopeteprivacy.so.1 libkopeteprivacy.so )
-( cd opt/kde/lib ; rm -rf liboscar.so.1 )
-( cd opt/kde/lib ; ln -sf liboscar.so.1.0.0 liboscar.so.1 )
-( cd opt/kde/lib ; rm -rf libkrdccore.so.4 )
-( cd opt/kde/lib ; ln -sf libkrdccore.so.4.3.0 libkrdccore.so.4 )
-( cd opt/kde/lib ; rm -rf libkopeteidentity.so )
-( cd opt/kde/lib ; ln -sf libkopeteidentity.so.1 libkopeteidentity.so )
-( cd opt/kde/lib ; rm -rf libkopete.so )
-( cd opt/kde/lib ; ln -sf libkopete.so.4 libkopete.so )
-( cd opt/kde/lib ; rm -rf libkopete_oscar.so.4 )
-( cd opt/kde/lib ; ln -sf libkopete_oscar.so.4.3.0 libkopete_oscar.so.4 )
-#%% begin initialize kdenetwork-4.3.5
+( cd opt/kde/share/doc/HTML/en/krdc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/krdc ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kppp ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kppp ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/krfb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/krfb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+#%% begin initialize kdenetwork-4.4.5
 if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
 	/bin/bash /opt/kde/bin/plamo_update_kde.sh
 fi
